var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1CharacterCount =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1CharacterCount.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1CharacterCount.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ]
];